@@ -36,7 +36,6 @@
 
 #include <QDebug>
 #include <QCheckBox>
-#include <QDialog>
 #include <QMenu>
 #include <QPushButton>
 #include <QtDBus/QtDBus>
@@ -48,22 +47,21 @@ K_PLUGIN_FACTORY(KWalletFactory, registerPlugin<KWalletConfig>();)
 
 KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args),
-      _cfg(KSharedConfig::openConfig(QLatin1String("kwalletrc"), KConfig::NoGlobals))
+      _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
 {
     KAboutData *about = new KAboutData(QStringLiteral("kcmkwallet5"),
                                        i18n("KDE Wallet Control Module"),
                                        QStringLiteral(KWALLETMANAGER_VERSION_STRING),
-                                       QStringLiteral(),
+                                       QString(),
                                        KAboutLicense::GPL,
                                        i18n("(c) 2003 George Staikos"));
     about->addAuthor(i18n("George Staikos"),
-                     QStringLiteral(),
+                     QString(),
                      QStringLiteral("staikos@kde.org"));
     setAboutData(about);
     setNeedsAuthorization(true);
 
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    //PORT QT5 vbox->setSpacing(KDialog::spacingHint());
     vbox->setMargin(0);
     _wcw = new WalletConfigWidget(this);
     vbox->addWidget(_wcw);
@@ -88,7 +86,7 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
     _wcw->_accessList->setContextMenuPolicy(Qt::CustomContextMenu);
     updateWalletLists();
 
-    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.kwalletmanager"))) {
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.kwalletmanager"))) {
         _wcw->_launch->hide();
     }
 
@@ -146,7 +144,7 @@ QString KWalletConfig::newWallet()
 void KWalletConfig::newLocalWallet()
 {
     const QString n = newWallet();
-    if (n.isEmpty()) {
+    if (n.trimmed().isEmpty()) {
         return;
     }
 
@@ -160,7 +158,7 @@ void KWalletConfig::newLocalWallet()
 void KWalletConfig::newNetworkWallet()
 {
     const QString n = newWallet();
-    if (n.isEmpty()) {
+    if (n.trimmed().isEmpty()) {
         return;
     }
 
@@ -173,12 +171,12 @@ void KWalletConfig::newNetworkWallet()
 
 void KWalletConfig::launchManager()
 {
-    if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QLatin1String("org.kde.kwalletmanager5"))) {
-        QProcess::startDetached(QLatin1String("kwalletmanager5 --show"));
+    if (!QDBusConnection::sessionBus().interface()->isServiceRegistered(QStringLiteral("org.kde.kwalletmanager5"))) {
+        QProcess::startDetached(QStringLiteral("kwalletmanager5 --show"));
     } else {
-        QDBusInterface kwalletd(QLatin1String("org.kde.kwalletmanager5"), QLatin1String("/kwalletmanager5/MainWindow_1"));
-        kwalletd.call(QLatin1String("show"));
-        kwalletd.call(QLatin1String("raise"));
+        QDBusInterface kwalletd(QStringLiteral("org.kde.kwalletmanager5"), QStringLiteral("/kwalletmanager5/MainWindow_1"));
+        kwalletd.call(QStringLiteral("show"));
+        kwalletd.call(QStringLiteral("raise"));
     }
 }
 
@@ -229,13 +227,13 @@ void KWalletConfig::load()
         // perform cleanup in the kwalletrc file, by removing entries that correspond to non-existent
         // (previously deleted, for example) wallets
         QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-        path.append(QString("/kwalletd/%1.kwl").arg(walletName));
+        path.append(QStringLiteral("/kwalletd/%1.kwl").arg(walletName));
         if (!QFile::exists(path)) {
             // if the wallet no longer exists, delete the entries from the configuration file and skip to next entry
-            KConfigGroup cfgAllow = KSharedConfig::openConfig("kwalletrc")->group("Auto Allow");
+            KConfigGroup cfgAllow = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group("Auto Allow");
             cfgAllow.deleteEntry(walletName);
 
-            KConfigGroup cfgDeny = KSharedConfig::openConfig("kwalletrc")->group("Auto Deny");
+            KConfigGroup cfgDeny = KSharedConfig::openConfig(QStringLiteral("kwalletrc"))->group("Auto Deny");
             cfgDeny.deleteEntry(walletName);
             continue;
         }
@@ -244,21 +242,22 @@ void KWalletConfig::load()
         const QStringList denyapps = ad.readEntry(*i, QStringList());
         denykeys.removeAll(walletName);
         QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << walletName);
-        for (QStringList::const_iterator j = apps.begin(); j != apps.end(); ++j) {
+
+        for (QStringList::const_iterator j = apps.begin(), end = apps.end(); j != end; ++j) {
             new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Allow"));
         }
-        for (QStringList::const_iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
+        for (QStringList::const_iterator j = denyapps.begin(), end = denyapps.end(); j != end; ++j) {
             new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Deny"));
         }
     }
-    for (QStringList::const_iterator i = denykeys.constBegin(); i != denykeys.constEnd(); ++i) {
+    for (QStringList::const_iterator i = denykeys.constBegin(), denykeysEnd = denykeys.constEnd(); i != denykeysEnd; ++i) {
         const QStringList denyapps = ad.readEntry(*i, QStringList());
         QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << *i);
-        for (QStringList::const_iterator j = denyapps.begin(); j != denyapps.end(); ++j) {
+        for (QStringList::const_iterator j = denyapps.begin(), denyappsEnd = denyapps.end(); j != denyappsEnd; ++j) {
             new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Deny"));
         }
     }
-    _wcw->_accessList->header()->setResizeMode(QHeaderView::ResizeToContents);
+    _wcw->_accessList->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     emit changed(false);
 }
 
@@ -275,8 +274,11 @@ void KWalletConfig::save()
     KAuth::ExecuteJob *j = action.execute();
 
     if (!j->exec()) {
-        qDebug() << j->errorText();
-        KMessageBox::error(this, j->errorString(), i18n("KDE Wallet Control Module"));
+        if (j->error() == KAuth::ActionReply::AuthorizationDeniedError) {
+            KMessageBox::error(this, i18n("Permission denied."), i18n("KDE Wallet Control Module"));
+        } else {
+            KMessageBox::error(this, i18n("Error while authenticating action:\n%1", j->errorString()), i18n("KDE Wallet Control Module"));
+        }
         load();
         return;
     }
@@ -336,12 +338,12 @@ void KWalletConfig::save()
     _cfg->sync();
 
     // this restarts kwalletd if necessary
-    QDBusInterface kwalletd(QLatin1String("org.kde.kwalletd5"), QLatin1String("/modules/kwalletd"), QLatin1String(KWALLETMANAGERINTERFACE));
+    QDBusInterface kwalletd(QStringLiteral("org.kde.kwalletd5"), QStringLiteral("/modules/kwalletd"), QStringLiteral(KWALLETMANAGERINTERFACE));
     // if wallet was deactivated, then kwalletd will exit upon start so check
     // the status before invoking reconfigure
     if (kwalletd.isValid()) {
         // this will eventually make kwalletd exit upon deactivation
-        kwalletd.call(QLatin1String("reconfigure"));
+        kwalletd.call(QStringLiteral("reconfigure"));
     }
 
     emit changed(false);
